@@ -1,10 +1,11 @@
 import json
 import requests
+from django.conf import settings
 
 # This is a class that is designed to include all methods and functions one needs to make an A.P.I. call
 class API(object):
 
-    _base_url = "https://explorer.eu.ngrok.io"
+    _base_url = "https://staging.ledger.nashglobal.co"
 
     # Most API calls require headers, params and payloads
     _headers = None
@@ -23,13 +24,16 @@ class API(object):
         self._headers = headers
         self._params = params
 
+        self._base_url=getattr(settings, 'LEDGER_URL', self._base_url)
+        # self._base_url='https://dev.ledger.nashglobal.co'
+
         requests.packages.urllib3.disable_warnings()
 
     # There are 3 types of API requests that most APIs use, POST, GET and PUT
     # This method will take the payload or data to be sent and send it to the required API url
     # using the desired method and returns the response
     def api_request(self, url, payload, method, verify = False, files = None):
-
+        
         if payload == "null":
             self._payload=json.dumps({})
         else:
