@@ -78,7 +78,14 @@ class BillPayments(Resource):
             additional_properties = payload.get("additional_properties", {})
 
             # If client type is Quickbooks Online
-            if super().get_client_type() == super().QBO:            
+            if super().get_client_type() == super().QBO: 
+                
+                self.urls.update({
+                    "new": f"/companies/{super().get_company_id()}/vendor_payments",
+                    "edit": f"/companies/{super().get_company_id()}/vendor_payments",
+                })
+
+                super().set_urls(self.urls)           
 
                 data = {"type": "PurchasePayment"}
 
@@ -94,6 +101,11 @@ class BillPayments(Resource):
                         "TotalAmt": payload.get("amount", 0)
                     })
 
+                if 'pay_type' in payload.keys():
+                    data.update({
+                        "PayType": payload.get("pay_type", 0)
+                    })
+
                 if 'vendor_id' in payload.keys():
                     data.update({
                         "VendorRef": {
@@ -101,6 +113,13 @@ class BillPayments(Resource):
                         }
                     })
 
+                if 'currency_code' in payload.keys():
+                    data.update({
+                        "CurrencyRef": {
+                            "value": payload.get("currency_code", "KES")
+                        }
+                    })
+
                 invoices = payload.get("invoice_payments", [])
 
                 for i in range(len(invoices)):
@@ -160,6 +179,18 @@ class BillPayments(Resource):
                         "date": payload.get("date", "")
                     })
 
+            # If client type is MS_DYNAMICS
+            elif super().get_client_type() == super().MS_DYNAMICS:
+                data.update({
+                    "paymentReference": payload.get("reference", ""),
+                    "ownerInvoiceType": "Vendor",
+                    "ownerInvoiceNumber": payload.get("invoice_id", ""),
+                    "ownerNumber": payload.get("vendor_id", ""),
+                    "description": payload.get("description", ""),
+                    "amount": payload.get("amount", ""),
+                    "bankCode": payload.get("bank_code", ""),
+                })
+
             data.update(additional_properties)
 
             return data
