@@ -1,5 +1,4 @@
 from erp_sync.Resources.resource import Resource
-from pyparsing import empty
 
 
 class Invoices(Resource):
@@ -71,7 +70,7 @@ class Invoices(Resource):
             super().set_urls(self.urls)        
         
         if date_from is not None and date_from != '':
-            self.urls["import"] = f'{self.urls["import"]}/?dateFromFilter={date_from}'
+            self.urls["import"] = f'{self.urls["import"]}?dateFromFilter={date_from}'
             super().set_urls(self.urls)
 
         return super().import_data(payload, method, endpoint)
@@ -161,6 +160,9 @@ class Invoices(Resource):
                 if "reference" in payload.keys():
                     data.update({"reference_number": payload.get("reference", "")})
 
+                if "invoice_number" in payload.keys():
+                    data.update({"invoice_number": payload.get("invoice_number", "")})
+
                 if "due_date" in payload.keys():
                     data.update({"due_date": payload.get("due_date", "")})
 
@@ -176,6 +178,19 @@ class Invoices(Resource):
                     if "quantity" in line_items[i].keys():
                         line_items[i]["quantity"] = line_items[i].pop("quantity")
 
+                    if "account_id" in line_items[i].keys():
+                        line_items[i].pop("account_id")
+                    if "type" in line_items[i].keys():
+                        line_items[i].pop("type")
+                    if "unit_of_measure" in line_items[i].keys():
+                        line_items[i].pop("unit_of_measure")
+                    if "tax_type" in line_items[i].keys():
+                        line_items[i].pop("tax_type")
+                    if "tax_id" in line_items[i].keys():
+                        line_items[i].pop("tax_id")
+                    if "unit_of_measure" in line_items[i].keys():
+                        line_items[i].pop("unit_of_measure")
+
                 # if line_items has data in it
                 if bool(line_items):
                     data.update({"line_items": line_items})
@@ -193,29 +208,41 @@ class Invoices(Resource):
                     )
 
                 if "currency_code" in payload.keys():
-                    data.update(
-                        {"CurrencyRef": {"value": payload.get("currency_code", "KES")}}
-                    )
+                    data.update({
+                        "CurrencyRef": {
+                            "value": payload.get("currency_code", "KES")
+                        }
+                    })
 
                 line_items = payload.get("line_items", [])
 
                 for i in range(len(line_items)):
                     line_items[i]["DetailType"] = "SalesItemLineDetail"
                     line_items[i]["Description"] = line_items[i].pop("description")
+                    line_items[i]["SalesItemLineDetail"] = {}
                     line_items[i]["Amount"] = line_items[i].get(
                         "price", 0
                     ) * line_items[i].get("quantity", 0)
 
                     if "item_ledger_id" in line_items[i].keys():
-                        line_items[i]["SalesItemLineDetail"] = {
-                            "ItemRef": {"value": line_items[i].pop("item_ledger_id", 0)}
-                        }
+                        line_items[i]["SalesItemLineDetail"]["ItemRef"] = {"value": line_items[i].pop("item_ledger_id", 0)}
 
                     if "price" in line_items[i].keys():
-                        line_items[i]["UnitPrice"] = line_items[i].pop("price")
+                        line_items[i]["SalesItemLineDetail"]["UnitPrice"] = line_items[i].pop("price")
 
                     if "quantity" in line_items[i].keys():
-                        line_items[i]["Qty"] = line_items[i].pop("quantity")
+                        line_items[i]["SalesItemLineDetail"]["Qty"] = line_items[i].pop("quantity")
+                    
+                    if "account_id" in line_items[i].keys():
+                        line_items[i].pop("account_id")
+                    if "type" in line_items[i].keys():
+                        line_items[i].pop("type")
+                    if "unit_of_measure" in line_items[i].keys():
+                        line_items[i].pop("unit_of_measure")
+                    if "tax_type" in line_items[i].keys():
+                        line_items[i].pop("tax_type")
+                    if "tax_id" in line_items[i].keys():
+                        line_items[i].pop("tax_id")
 
                 # if line_items has data in it
                 if bool(line_items):
@@ -421,17 +448,53 @@ class Invoices(Resource):
                     if "tax_id" in line_items[i].keys():
                         line_items[i]["tax_ids"] = [line_items[i].pop("tax_id")]
 
-                    if "description" in payload.keys():
+                    if "description" in line_items[i].keys():
                         line_items[i].pop("description")
-                    if "account_id" in payload.keys():
+                    if "account_id" in line_items[i].keys():
                         line_items[i].pop("account_id")
-                    if "tax_type" in payload.keys():
+                    if "tax_type" in line_items[i].keys():
                         line_items[i].pop("tax_type")
 
                 # if line_items has data in it
                 if bool(line_items):
                     data.update({"invoice_line_ids": line_items})
 
+            # If client type is MS_DYNAMICS
+            elif super().get_client_type() == super().MS_DYNAMICS:
+                data.pop("type")
+                data.update({
+                    "customerNumber": f'{payload.get("customer_ledger_id", "")}'
+                })
+
+                line_items = payload.get("line_items", [])
+
+                for i in range(len(line_items)):
+                    if "item_ledger_id" in line_items[i].keys():
+                        line_items[i]["item_id"] = line_items[i].pop(
+                            "item_ledger_id"
+                        )
+                    if "quantity" in line_items[i].keys():
+                        line_items[i]["quantity"] = line_items[i].pop("quantity")
+                    if "price" in line_items[i].keys():
+                        line_items[i]["unit_price"] = line_items[i].pop("price")
+                    if "type" in line_items[i].keys():
+                        line_items[i]["type"] = line_items[i].pop("type")
+                    if "unit_of_measure" in line_items[i].keys():
+                        line_items[i]["unit_of_measure"] = line_items[i].pop("unit_of_measure")
+
+                    if "account_id" in line_items[i].keys():
+                        line_items[i].pop("account_id")
+                    if "description" in line_items[i].keys():
+                        line_items[i].pop("description")
+                    if "tax_type" in line_items[i].keys():
+                        line_items[i].pop("tax_type")
+                    if "tax_id" in line_items[i].keys():
+                        line_items[i].pop("tax_id")
+
+                # if line_items has data in it
+                if bool(line_items):
+                    data.update({"create_customer_invoice_details": line_items})
+                    
             data.update(additional_properties)
 
             return data
@@ -461,10 +524,11 @@ class Invoices(Resource):
                         if "total_amount" in data[i].keys():
                             data[i]["amount"] = data[i].pop("total_amount")
 
-            if "invoices" in payload.keys():
-                payload["invoices"] = data
-            elif "resource" in payload.keys():
-                payload["resource"] = data
+            if isinstance(payload, dict):
+                if "invoices" in payload.keys():
+                    payload["invoices"] = data
+                elif "resource" in payload.keys():
+                    payload["resource"] = data
 
             super().set_response(payload)
 
