@@ -119,44 +119,51 @@ class Payments(Resource):
                         }
                     })
 
-                if 'account_id' in payload.keys():
+                if 'currency_code' in payload.keys():
                     data.update({
-                        "DepositToAccountRef": {
-                            "value": payload.get("account_id", "")
+                        "CurrencyRef": {
+                            "value": payload.get("currency_code", "KES")
                         }
                     })
 
-                if 'reference' in payload.keys():
-                    data.update({
-                        "PaymentRefNum": payload.get("reference", "")
-                    })
+                # if 'account_id' in payload.keys():
+                #     data.update({
+                #         "DepositToAccountRef": {
+                #             "value": payload.get("account_id", "")
+                #         }
+                #     })
+
+                # if 'reference' in payload.keys():
+                #     data.update({
+                #         "PaymentRefNum": payload.get("reference", "")
+                #     })
                 
-                invoices = payload.get("invoice_payments", [])
+                # invoices = payload.get("invoice_payments", [])
 
-                for i in range(len(invoices)):
-                    invoice = {}
-                    if 'amount' in invoices[i].keys():
-                        invoice.update({
-                            "Amount": invoices[i].get("amount", "")
-                        })
+                # for i in range(len(invoices)):
+                #     invoice = {}
+                #     if 'amount' in invoices[i].keys():
+                #         invoice.update({
+                #             "Amount": invoices[i].get("amount", "")
+                #         })
 
-                    if 'invoice_id' in invoices[i].keys():
-                        invoice.update({
-                            "LinkedTxn": [
-                                {
-                                    "TxnId": invoices[i].get('invoice_id',""),
-                                    "TxnType": "Invoice"
-                                }
-                            ]
-                        })
+                #     if 'invoice_id' in invoices[i].keys():
+                #         invoice.update({
+                #             "LinkedTxn": [
+                #                 {
+                #                     "TxnId": invoices[i].get('invoice_id',""),
+                #                     "TxnType": "Invoice"
+                #                 }
+                #             ]
+                #         })
                     
-                    invoices[i] = invoice
+                #     invoices[i] = invoice
 
-                # if invoices has data in it
-                if bool(invoices):
-                    data.update({
-                        "Line": invoices
-                    })
+                # # if invoices has data in it
+                # if bool(invoices):
+                #     data.update({
+                #         "Line": invoices
+                #     })
 
             # If client type is ZOHO
             elif super().get_client_type() == super().ZOHO:
@@ -354,6 +361,20 @@ class Payments(Resource):
                     "partner_id": payload.get("customer_id", ""),
                     "payment_reference": payload.get("reference", ""),
                 }
+
+            # If client type is MS_DYNAMICS
+            elif super().get_client_type() == super().MS_DYNAMICS:
+                data.pop("type")
+                data.update({
+                    "paymentReference": payload.get("reference", ""),
+                    "ownerInvoiceType": "Customer",
+                    "ownerInvoiceNumber": f'{payload.get("invoice_id", "")}',
+                    "ownerNumber": payload.get("customer_id", ""),
+                    "description": payload.get("description", ""),
+                    "amount": f'{payload.get("amount", "")}',
+                    "bankCode": payload.get("bank_code", ""),
+                })
+
             data.update(additional_properties)
 
             return data
